#!/bin/bash
#
# packager                          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#
# o trouver les sources : http://sourceforge.net/projects/mjpeg
#
# dernires rvisions       : 12/1/2009
#
# fichiers additionnels :
#

softname='mjpegtools'
softversion='1.9.0'
packageversion='54.1'

#
# ZenWalk standard: type CPUet architecture
#
# arch='i486' -> le compileur utilise seulement les instructions 80486
# cpu='i686'  -> optimisation fate pour PII et >
#
arch='i486'
cpu='i686'

#
# destination du package
#
prefix=/usr

#
# log
#
(

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# "gros" PC: 6 compilations  la fois
#
# numjobs='-j6'
#
# "lger" PC: 2 compilations  la fois
#
numjobs='-j2'

#
# paramtres pour compiler
#
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://downloads.sourceforge.net/mjpeg/$softname-$softversion.tar.gz

#
# preparer le rpertoire qui accueillera la compilation
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/src/$softname-$softversion

#
# mettre le slack-desc en place. 
#
cat <<EOF > $dest/install/slack-desc
          |-----handy-ruler------------------------------------------------------|
mjpegtools: Mjpeg - tools to edit, playback, compress MPEG
mjpegtools:
mjpegtools: 
mjpegtools: Mjpeg tools is a suite of programs which support video capture, 
mjpegtools: editing, playback and compression to MPEG of MJPEG video..
mjpegtools: 
mjpegtools: 
mjpegtools:
mjpegtools: 
mjpegtools:
mjpegtools: 
EOF

#
# Verifie si package est present
#
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

#
# extraire les sources
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
tar xvzf $srcpkg
cd $src

#
# configurer le package pour la compilation
#

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    echo "echo $CFLAGS" > cpuinfo.sh
    ./configure \
      --prefix=$prefix \
      --sysconfdir="/etc" \
      --localstatedir="/var/lib" \
	  --mandir="/usr/man" \
      --infodir="/usr/info" \
	  --enable-static="no" \
	  --enable-shared="yes" \
	  --build=$arch-slackware-linux || exit
#
# "faire" le package package
#
    #find . -type f -exec sed 's/\-O3//g' -i '{}' \;
    make $numjobs DESTDIR=$dest

#
# installer le package dans son rpertoire de destination
#
    make install DESTDIR=$dest

#
# ajout des fichiers de docs, infos, ...
#
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS PLANS INSTALL HINTS COPYING NEWS README TODO CHANGES ChangeLog\
      $dest/usr/doc/$softname-$softversion

#
# Stripper les xcutables
# (Commenter ces lignes si besoin d'infos de dbuggage)
#
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#
# Compresser les pages Man
#
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)


# Compresser les pages Info
#
( cd $dest/$prefix/info
  find . -name "*.info" | xargs gzip -9
)

#
# Mettre le zenbuild  sa place
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

#
# fixer les permissions
#
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#
# fabriquer le zenpackage
#
cd $dest
makepkg -l y -c n $dest.tgz

#
# produire la signature md5 du package
#
cd $buildir
md5sum $package.tgz > $package.md5


#
# produire le fichier src
#
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/ap/mjpegtools/source/build-mjpegtools.sh > $package.src
echo $source >> $package.src


#
# produire le fichier .dep
#
cd $buildir
echo -e "atk,cxxlibs,expat,fontconfig,freetype,gcc,glib2,gtk+2,libdv,libjpeg,libpng,\
libquicktime,libmikmod,pango,sdl,xorg,zlib" > $package.dep

#
# supprimer source
#
rm -rf $src
rm -rf $dest

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
